@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -24,7 +25,6 @@ class MocIgnoreFile: public FileAccess
   public:
     MocIgnoreFile()
     {
-        //assert(false);
         mJobHandler.reset(new FileAccessJobHandlerMoc(this));
         /*
           FileAccess set file calls our overriden loadData to actually get file meta data.
@@ -44,19 +44,19 @@ class MocIgnoreFile: public FileAccess
         m_name = ".cvsignore";
         setUrl(QUrl("/test/ui/.cvsignore"));
     }
-    void addPath(const QString& txt, bool /*reinit*/=true) override { Q_UNUSED(txt); }
+    void addPath([[maybe_unused]] const QString& txt, bool /*reinit*/ = true) override {}
     bool createLocalCopy() override { return true; }
 
-    Q_REQUIRED_RESULT qint64 size() const override { return 0; };
+    [[nodiscard]] qint64 size() const override { return 0; };
 
-    Q_REQUIRED_RESULT bool isFile() const override {return true;};
-    Q_REQUIRED_RESULT bool isDir() const override {return false;};
-    Q_REQUIRED_RESULT bool isSymLink() const override {return false;};
-    Q_REQUIRED_RESULT bool exists() const override {return m_bExists; };
-    Q_REQUIRED_RESULT bool isReadable() const override {return m_bReadable;};
-    Q_REQUIRED_RESULT bool isWritable() const override {return m_bWritable;};
-    Q_REQUIRED_RESULT bool isExecutable() const override {return m_bExecutable;};
-    Q_REQUIRED_RESULT bool isHidden() const override { return m_bHidden; };
+    [[nodiscard]] bool isFile() const override { return true; };
+    [[nodiscard]] bool isDir() const override { return false; };
+    [[nodiscard]] bool isSymLink() const override { return false; };
+    [[nodiscard]] bool exists() const override { return m_bExists; };
+    [[nodiscard]] bool isReadable() const override { return m_bReadable; };
+    [[nodiscard]] bool isWritable() const override { return m_bWritable; };
+    [[nodiscard]] bool isExecutable() const override { return m_bExecutable; };
+    [[nodiscard]] bool isHidden() const override { return m_bHidden; };
 
     bool readFile(void*  /*pDestBuffer*/, qint64  /*maxLength*/) override { return true;};
     bool writeFile(const void* /*pSrcBuffer*/, qint64 /*length*/) override { return true; };
