@@ -1,3 +1,4 @@
+// clang-format off
 /**
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -5,24 +6,24 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
+// clang-format on
 
 #ifndef SOURCEDATAMOC_H
 #define SOURCEDATAMOC_H
 
 #include "../SourceData.h"
 
+#include <memory>
+
 class SourceDataMoc: public SourceData
 {
   private:
-    QSharedPointer<Options> defualtOptions = QSharedPointer<Options>::create();
+    std::unique_ptr<Options> defualtOptions = std::make_unique<Options>();
 
   public:
-    SourceDataMoc()
-    {
-        setOptions(defualtOptions);
-    }
+    SourceDataMoc() = default;
 
-    [[nodiscard]] const QSharedPointer<Options>& options() { return defualtOptions; }
+    [[nodiscard]] const std::unique_ptr<Options>& options() { return defualtOptions; }
 };
 
 #endif /* SOURCEDATAMOC_H */
