@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -15,45 +16,12 @@
 
 #include <QAtomicInt>
 #include <QString>
-
-#define KF_VERSION_CHECK(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-#define KF_VERSION KF_VERSION_CHECK(KF_VERSION_MAJOR, KF_VERSION_MINOR, KF_VERSION_PATCH)
-
-template <class T>
-T min3( T d1, T d2, T d3 )
-{
-   return std::min( std::min( d1, d2 ), d3 );
-}
-
-template <class T>
-T max3( T d1, T d2, T d3 )
-{
-   return std::max( std::max( d1, d2 ), d3 );
-}
-
-inline qint32 getAtomic(QAtomicInt& ai)
-{
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return ai.load();
-#else
-    return ai.loadRelaxed();
-#endif
-}
-
-inline qint64 getAtomic(QAtomicInteger<qint64>& ai)
-{
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return ai.load();
-#else
-    return ai.loadRelaxed();
-#endif
-}
+#include <QStringList>
 
 class QFont;
 class QColor;
 class QSize;
 class QPoint;
-class QStringList;
 class QTextStream;
 
 class ValueMap
@@ -68,7 +36,6 @@ class ValueMap
     void save(QTextStream& ts);
     void load(QTextStream& ts);
     QString getAsString();
-    // void load( const QString& s );
 
     virtual void writeEntry(const QString&, const QFont&);
     virtual void writeEntry(const QString&, const QColor&);
