@@ -45,7 +45,7 @@ qint32 LineData::width(qint32 tabSize) const
     const QString pLine = getLine();
     qint32 w = 0;
     qint32 j = 0;
-    for(QtSizeType i = 0; i < size(); ++i)
+    for(qsizetype i = 0; i < size(); ++i)
     {
         if(pLine[i] == '\t')
         {
@@ -607,7 +607,7 @@ bool ManualDiffHelpEntry::isValidMove(LineRef line1, LineRef line2, e_SrcSelecto
 
 qint32 ManualDiffHelpEntry::calcManualDiffFirstDiff3LineIdx(const Diff3LineVector& d3lv)
 {
-    QtSizeType i;
+    size_t i;
     for(i = 0; i < d3lv.size(); ++i)
     {
         const Diff3Line* d3l = d3lv[i];
@@ -675,7 +675,7 @@ void DiffList::runDiff(const std::shared_ptr<LineDataVector>& p1, const size_t i
 
         if(empty())
         {
-            qint32 numofEquals = std::min(size1, size2);
+            LineType numofEquals = std::min(size1, size2);
             Diff d(numofEquals, size1 - numofEquals, size2 - numofEquals);
 
             push_back(d);
@@ -1218,6 +1218,8 @@ void DiffBufferInfo::init(Diff3LineList* pD3ll,
 void Diff3LineList::calcWhiteDiff3Lines(
     const std::shared_ptr<LineDataVector> &pldA, const std::shared_ptr<LineDataVector> &pldB, const std::shared_ptr<LineDataVector> &pldC, const bool bIgnoreComments)
 {
+    assert(empty() || (pldA != nullptr && pldB != nullptr && pldC != nullptr));
+    // Init white line flags
     for(Diff3Line& diff3Line: *this)
     {
         diff3Line.bWhiteLineA = (!diff3Line.getLineA().isValid() || (*pldA)[diff3Line.getLineA()].whiteLine() || (bIgnoreComments && (*pldA)[diff3Line.getLineA()].isPureComment()));
@@ -1558,9 +1560,9 @@ bool Diff3LineList::fineDiff(const e_SrcSelector selector, const std::shared_ptr
 // Convert the list to a vector of pointers
 void Diff3LineList::calcDiff3LineVector(Diff3LineVector& d3lv)
 {
-    d3lv.resize(SafeInt<QtSizeType>(size()));
+    d3lv.resize(size());
     Diff3LineList::iterator i;
-    QtSizeType j = 0;
+    size_t j = 0;
     for(i = begin(); i != end(); ++i, ++j)
     {
         d3lv[j] = &(*i);
