@@ -48,7 +48,6 @@
 #include <QRunnable>
 #include <QScrollBar>
 #include <QStatusBar>
-#include <QTextCodec>
 #include <QTextLayout>
 #include <QThread>
 #include <QtMath>
@@ -59,7 +58,7 @@ QPointer<QScrollBar> DiffTextWindow::mVScrollBar = nullptr;
 std::vector<RecalcWordWrapThread*> DiffTextWindow::s_runnables; //Used in startRunnables and recalWordWrap
 
 /*
-    QRunnable is not enough here be may appear to work depending on configuration.
+    QRunnable is not enough here. It may appear to work depending on configuration.
     That is an artifact of the threads being short-lived. Never the less such code is
     not safe because of a potenial race condition on exit.
 
@@ -150,11 +149,12 @@ class DiffTextWindowData
         const Diff3LineVector* pDiff3LineVector,
         const ManualDiffHelpList* pManualDiffHelpList)
     {
+        //wait for all helper threads to finish
+        reset();
         m_filename = filename;
         m_pLineData = pLineData;
         m_size = size;
         mDiff3LineVector = pDiff3LineVector;
-        m_diff3WrapLineVector.clear();
         m_pManualDiffHelpList = pManualDiffHelpList;
 
         mTextEncoding = QString::fromLatin1(encoding);
@@ -173,7 +173,6 @@ class DiffTextWindowData
         m_bMyUpdate = false;
         m_fastSelectorLine1 = 0;
         m_fastSelectorNofLines = 0;
-        m_lineNumberWidth = 0;
         m_maxTextWidth = -1;
 
         m_pLineData = nullptr;
@@ -187,16 +186,15 @@ class DiffTextWindowData
     [[nodiscard]] QString getLineString(const qint32 line) const;
 
     void writeLine(
-        RLPainter& p, const LineData* pld,
+        RLPainter& p,
         const std::shared_ptr<const DiffList>& pLineDiff1, const std::shared_ptr<const DiffList>& pLineDiff2, const LineRef& line,
         const ChangeFlags whatChanged, const ChangeFlags whatChanged2, const LineRef& srcLineIdx,
         qint32 wrapLineOffset, qint32 wrapLineLength, bool bWrapLine, const QRect& invalidRect);
 
-    void draw(RLPainter& p, const QRect& invalidRect, const qint32 beginLine, const LineRef& endLine);
-
     void myUpdate(qint32 afterMilliSecs);
 
-    [[nodiscard]] qint32 leftInfoWidth() const { return 4 + m_lineNumberWidth; } // Number of information columns on left side
+    //TODO: Fix after line number area is converted to a QWidget.
+    [[nodiscard]] qint32 leftInfoWidth() const { return 4 + (gOptions->m_bShowLineNumbers ? m_pDiffTextWindow->getLineNumberWidth() : 0); } // Number of information columns on left side
     [[nodiscard]] LineRef convertLineOnScreenToLineInSource(const qint32 lineOnScreen, const e_CoordType coordType, const bool bFirstLine) const;
 
     void prepareTextLayout(QTextLayout& textLayout, qint32 visibleTextWidth = -1);
@@ -205,9 +203,42 @@ class DiffTextWindowData
     [[nodiscard]] const QString& getFileName() const { return m_filename; }
 
     [[nodiscard]] const Diff3LineVector* getDiff3LineVector() const { return mDiff3LineVector; }
+
+    [[nodiscard]] const Diff3WrapLineVector& getDiff3WrapLineVector() { return m_diff3WrapLineVector; }
+    [[nodiscard]] bool hasLineData() const { return m_pLineData != nullptr && !m_pLineData->empty(); }
+
+    void initColors()
+    {
+        if(getWindowIndex() == e_SrcSelector::A)
+        {
+            m_cThis = gOptions->aColor();
+            m_cDiff1 = gOptions->bColor();
+            m_cDiff2 = gOptions->cColor();
+        }
+        else if(getWindowIndex() == e_SrcSelector::B)
+        {
+            m_cThis = gOptions->bColor();
+            m_cDiff1 = gOptions->cColor();
+            m_cDiff2 = gOptions->aColor();
+        }
+        else if(getWindowIndex() == e_SrcSelector::C)
+        {
+            m_cThis = gOptions->cColor();
+            m_cDiff1 = gOptions->aColor();
+            m_cDiff2 = gOptions->bColor();
+        }
+        m_cDiffBoth = gOptions->conflictColor(); // Conflict color
+    }
+
+    [[nodiscard]] QColor thisColor() const { return m_cThis; }
+    [[nodiscard]] QColor diff1Color() const { return m_cDiff1; }
+    [[nodiscard]] QColor diff2Color() const { return m_cDiff2; }
+    [[nodiscard]] QColor diffBothColor() const { return m_cDiffBoth; }
+    [[nodiscard]] const Diff3LineVector* diff3LineVector() { return mDiff3LineVector; }
+
   private:
     friend DiffTextWindow;
-    e_SrcSelector getWindowIndex() const { return m_pDiffTextWindow->getWindowIndex(); }
+    [[nodiscard]] e_SrcSelector getWindowIndex() const { return m_pDiffTextWindow->getWindowIndex(); }
 
     QPointer<DiffTextWindow> m_pDiffTextWindow;
     QString mTextEncoding;
@@ -235,7 +266,6 @@ class DiffTextWindowData
     LineRef m_firstLine = 0;
     LineRef m_oldFirstLine;
     qint32 m_horizScrollOffset = 0;
-    qint32 m_lineNumberWidth = 0;
     QAtomicInt m_maxTextWidth = -1;
 
     Selection m_selection;
@@ -361,7 +391,9 @@ void DiffTextWindow::setupConnections(const KDiff3App* app)
     chk_connect_a(app, &KDiff3App::selectAll, this, &DiffTextWindow::slotSelectAll);
     chk_connect_a(app, &KDiff3App::copy, this, &DiffTextWindow::slotCopy);
 
-    connections.push_back(KDiff3App::allowCopy.connect(boost::bind(&DiffTextWindow::canCopy, this)));
+    chk_connect_a(this, &DiffTextWindow::scrollToH, app, &KDiff3App::slotScrollToH);
+
+    connections.push_back(StandardMenus::allowCopy.connect(boost::bind(&DiffTextWindow::canCopy, this)));
     connections.push_back(KDiff3App::getSelection.connect(boost::bind(&DiffTextWindow::getSelection, this)));
 }
 
@@ -373,12 +405,9 @@ void DiffTextWindow::slotRefresh()
 
 void DiffTextWindow::slotSelectAll()
 {
-    LineRef l;
-    QtSizeType p = 0; // needed as dummy return values
-
     if(hasFocus())
     {
-        setSelection(0, 0, getNofLines(), 0, l, p);
+        setSelection(0, 0, getNofLines(), 0);
     }
 }
 
@@ -553,7 +582,7 @@ LineType DiffTextWindow::getNofLines() const
 LineType DiffTextWindow::convertLineToDiff3LineIdx(const LineRef line) const
 {
     if(line.isValid() && d->m_bWordWrap && d->m_diff3WrapLineVector.size() > 0)
-        return d->m_diff3WrapLineVector[std::min<QtSizeType>(line, d->m_diff3WrapLineVector.size() - 1)].diff3LineIndex;
+        return d->m_diff3WrapLineVector[std::min<size_t>(line, d->m_diff3WrapLineVector.size() - 1)].diff3LineIndex;
     else
         return line;
 }
@@ -563,7 +592,7 @@ LineRef DiffTextWindow::convertDiff3LineIdxToLine(const LineType d3lIdx) const
     assert(d3lIdx >= 0);
 
     if(d->m_bWordWrap && d->getDiff3LineVector() != nullptr && d->getDiff3LineVector()->size() > 0)
-        return (*d->getDiff3LineVector())[std::min((QtSizeType)d3lIdx, d->getDiff3LineVector()->size() - 1)]->sumLinesNeededForDisplay();
+        return (*d->getDiff3LineVector())[std::min((size_t)d3lIdx, d->getDiff3LineVector()->size() - 1)]->sumLinesNeededForDisplay();
     else
         return d3lIdx;
 }
@@ -587,7 +616,7 @@ LineRef getBestFirstLine(LineRef line, LineType nofLines, LineRef firstLine, Lin
         newFirstLine = std::max(0, (LineType)std::ceil(line - (visibleLines - nofLines) / 2));
     else
     {
-        qint32 numberPages = std::floor(nofLines / visibleLines);
+        LineType numberPages = (LineType)std::floor(nofLines / visibleLines);
         newFirstLine = std::max(0, line - (visibleLines * numberPages) / 3);
     }
     return newFirstLine;
@@ -659,7 +688,7 @@ void DiffTextWindow::mousePressEvent(QMouseEvent* e)
     {
         LineRef line;
         qint32 pos;
-        convertToLinePos(e->x(), e->y(), line, pos);
+        convertToLinePos(e->pos().x(), e->pos().y(), line, pos);
         qCInfo(kdiffDiffTextWindow) << "Left Button detected,";
         qCDebug(kdiffDiffTextWindow) << "line = " << line << ", pos = " << pos;
 
@@ -667,7 +696,7 @@ void DiffTextWindow::mousePressEvent(QMouseEvent* e)
         qint32 fontWidth = fontMetrics().horizontalAdvance('0');
         qint32 xOffset = d->leftInfoWidth() * fontWidth;
 
-        if((!gOptions->m_bRightToLeftLanguage && e->x() < xOffset) || (gOptions->m_bRightToLeftLanguage && e->x() > width() - xOffset))
+        if((!gOptions->m_bRightToLeftLanguage && e->pos().x() < xOffset) || (gOptions->m_bRightToLeftLanguage && e->pos().x() > width() - xOffset))
         {
             Q_EMIT setFastSelectorLine(convertLineToDiff3LineIdx(line));
             d->m_selection.reset(); // Disable current d->m_selection
@@ -697,7 +726,7 @@ void DiffTextWindow::mouseDoubleClickEvent(QMouseEvent* e)
     {
         LineRef line;
         qint32 pos;
-        convertToLinePos(e->x(), e->y(), line, pos);
+        convertToLinePos(e->pos().x(), e->pos().y(), line, pos);
         qCInfo(kdiffDiffTextWindow) << "Left Button detected,";
         qCDebug(kdiffDiffTextWindow) << "line = " << line << ", pos = " << pos;
 
@@ -705,14 +734,14 @@ void DiffTextWindow::mouseDoubleClickEvent(QMouseEvent* e)
         QString s;
         if(d->m_bWordWrap)
         {
-            if(!line.isValid() || line >= d->m_diff3WrapLineVector.size())
+            if(!line.isValid() || (size_t)line >= d->m_diff3WrapLineVector.size())
                 return;
             const Diff3WrapLine& d3wl = d->m_diff3WrapLineVector[line];
             s = d->getString(d3wl.diff3LineIndex).mid(d3wl.wrapLineOffset, d3wl.wrapLineLength);
         }
         else
         {
-            if(!line.isValid() || line >= d->getDiff3LineVector()->size())
+            if(!line.isValid() || (size_t)line >= d->getDiff3LineVector()->size())
                 return;
             s = d->getString(line);
         }
@@ -720,7 +749,7 @@ void DiffTextWindow::mouseDoubleClickEvent(QMouseEvent* e)
         if(!s.isEmpty())
         {
             const bool selectionWasEmpty = d->m_selection.isEmpty();
-            QtSizeType pos1, pos2;
+            qsizetype pos1, pos2;
             Utils::calcTokenPos(s, pos, pos1, pos2);
 
             resetSelection();
@@ -766,7 +795,7 @@ void DiffTextWindow::mouseMoveEvent(QMouseEvent* e)
     qCInfo(kdiffDiffTextWindow) << "Mouse Moved";
     qCDebug(kdiffDiffTextWindow) << "d->m_lastKnownMousePos = " << d->m_lastKnownMousePos << ", e->pos() = " << e->pos();
 
-    convertToLinePos(e->x(), e->y(), line, pos);
+    convertToLinePos(e->pos().x(), e->pos().y(), line, pos);
     d->m_lastKnownMousePos = e->pos();
 
     qCDebug(kdiffDiffTextWindow) << "line = " << line << ", pos = " << pos;
@@ -790,16 +819,16 @@ void DiffTextWindow::mouseMoveEvent(QMouseEvent* e)
         //FIXME: Why are we manually doing Layout adjustments?
         if(!gOptions->m_bRightToLeftLanguage)
         {
-            if(e->x() < d->leftInfoWidth() * fontWidth) deltaX = -1 - abs(e->x() - d->leftInfoWidth() * fontWidth) / fontWidth;
-            if(e->x() > width()) deltaX = +1 + abs(e->x() - width()) / fontWidth;
+            if(e->pos().x() < d->leftInfoWidth() * fontWidth) deltaX = -1 - abs(e->pos().x() - d->leftInfoWidth() * fontWidth) / fontWidth;
+            if(e->pos().x() > width()) deltaX = +1 + abs(e->pos().x() - width()) / fontWidth;
         }
         else
         {
-            if(e->x() > width() - 1 - d->leftInfoWidth() * fontWidth) deltaX = +1 + abs(e->x() - (width() - 1 - d->leftInfoWidth() * fontWidth)) / fontWidth;
-            if(e->x() < fontWidth) deltaX = -1 - abs(e->x() - fontWidth) / fontWidth;
+            if(e->pos().x() > width() - 1 - d->leftInfoWidth() * fontWidth) deltaX = +1 + abs(e->pos().x() - (width() - 1 - d->leftInfoWidth() * fontWidth)) / fontWidth;
+            if(e->pos().x() < fontWidth) deltaX = -1 - abs(e->pos().x() - fontWidth) / fontWidth;
         }
-        if(e->y() < 0) deltaY = -1 - (qint32)std::pow<qint32, qint32>(e->y(), 2) / (qint32)std::pow(fm.lineSpacing(), 2);
-        if(e->y() > height()) deltaY = 1 + (qint32)std::pow(e->y() - height(), 2) / (qint32)std::pow(fm.lineSpacing(), 2);
+        if(e->pos().y() < 0) deltaY = -1 - (qint32)std::pow<qint32, qint32>(e->pos().y(), 2) / (qint32)std::pow(fm.lineSpacing(), 2);
+        if(e->pos().y() > height()) deltaY = 1 + (qint32)std::pow(e->pos().y() - height(), 2) / (qint32)std::pow(fm.lineSpacing(), 2);
         if((deltaX != 0 && d->m_scrollDeltaX != deltaX) || (deltaY != 0 && d->m_scrollDeltaY != deltaY))
         {
             d->m_scrollDeltaX = deltaX;
@@ -822,6 +851,7 @@ void DiffTextWindow::wheelEvent(QWheelEvent* pWheelEvent)
 {
     QPoint delta = pWheelEvent->angleDelta();
 
+    pWheelEvent->ignore();
     //Block diagonal scrolling easily generated unintentionally with track pads.
     if(delta.y() != 0 && abs(delta.y()) > abs(delta.x()) && mVScrollBar != nullptr)
     {
@@ -876,7 +906,7 @@ void DiffTextWindow::timerEvent(QTimerEvent*)
 
     if(d->m_scrollDeltaX != 0 || d->m_scrollDeltaY != 0)
     {
-        QtSizeType newPos = d->m_selection.getLastPos() + d->m_scrollDeltaX;
+        qsizetype newPos = d->m_selection.getLastPos() + d->m_scrollDeltaX;
         try
         {
             LineRef newLine = d->m_selection.getLastLine() + d->m_scrollDeltaY;
@@ -912,7 +942,7 @@ void DiffTextWindow::convertToLinePos(qint32 x, qint32 y, LineRef& line, qint32&
     else
         line = LineRef::invalid;
 
-    if(line.isValid() && (!gOptions->wordWrapOn() || line < d->m_diff3WrapLineVector.count()))
+    if(line.isValid() && (!gOptions->wordWrapOn() || (size_t)line < d->m_diff3WrapLineVector.size()))
     {
         QString s = d->getLineString(line);
         QTextLayout textLayout(s, font(), this);
@@ -1050,7 +1080,6 @@ void DiffTextWindowData::prepareTextLayout(QTextLayout& textLayout, qint32 visib
 */
 void DiffTextWindowData::writeLine(
     RLPainter& p,
-    const LineData* pld,
     const std::shared_ptr<const DiffList>& pLineDiff1,
     const std::shared_ptr<const DiffList>& pLineDiff2,
     const LineRef& line,
@@ -1062,6 +1091,10 @@ void DiffTextWindowData::writeLine(
     bool bWrapLine,
     const QRect& invalidRect)
 {
+    //TODO: Fix after line number area is converted to a QWidget.
+    const qint32 lineNumberWidth = gOptions->m_bShowLineNumbers ? m_pDiffTextWindow->getLineNumberWidth() : 0;
+
+    const LineData* pld = !srcLineIdx.isValid() ? nullptr : &(*m_pLineData)[srcLineIdx]; // Text in this line;
     QFont normalFont = p.font();
 
     const QFontMetrics& fm = p.fontMetrics();
@@ -1096,21 +1129,21 @@ void DiffTextWindowData::writeLine(
     p.setPen(penColor);
     if(changed == BChanged)
     {
-        penColor = m_cDiff2;
+        penColor = diff2Color();
     }
     else if(changed == AChanged)
     {
-        penColor = m_cDiff1;
+        penColor = diff1Color();
     }
     else if(changed == Both)
     {
-        penColor = m_cDiffBoth;
+        penColor = diffBothColor();
     }
 
     if(pld != nullptr)
     {
         // First calculate the "changed" information for each character.
-        QtSizeType i = 0;
+        qsizetype i = 0;
         QString lineString = pld->getLine();
         if(!lineString.isEmpty())
         {
@@ -1137,7 +1170,7 @@ void DiffTextWindowData::writeLine(
 
         qint32 outPos = 0;
 
-        QtSizeType lineLength = m_bWordWrap ? wrapLineOffset + wrapLineLength : lineString.length();
+        qsizetype lineLength = m_bWordWrap ? wrapLineOffset + wrapLineLength : lineString.length();
 
         FormatRangeHelper frh;
 
@@ -1159,7 +1192,7 @@ void DiffTextWindowData::writeLine(
                 penColor2 = m_cDiffBoth;
             }
 
-            if(penColor != gOptions->foregroundColor() && whatChanged2 == NoChange && !gOptions->m_bShowWhiteSpace)
+            if(penColor2 != gOptions->foregroundColor() && whatChanged2 == NoChange && !gOptions->m_bShowWhiteSpace)
             {
                 // The user doesn't want to see highlighted white space.
                 penColor2 = gOptions->foregroundColor();
@@ -1196,8 +1229,8 @@ void DiffTextWindowData::writeLine(
     p.fillRect(0, yOffset, leftInfoWidth() * fontWidth, fontHeight, gOptions->backgroundColor());
 
     //TODO: Fix after line number area is converted to a QWidget.
-    xOffset = (m_lineNumberWidth + 2) * fontWidth;
-    qint32 xLeft = m_lineNumberWidth * fontWidth;
+    xOffset = (lineNumberWidth + 2) * fontWidth + m_pDiffTextWindow->contentsMargins().left() + 2;
+    qint32 xLeft = lineNumberWidth * fontWidth + m_pDiffTextWindow->contentsMargins().left() + 2;
     p.setPen(gOptions->foregroundColor());
     if(pld != nullptr)
     {
@@ -1205,7 +1238,7 @@ void DiffTextWindowData::writeLine(
         {
             QString num = QString::number(srcLineIdx + 1);
             assert(!num.isEmpty());
-            p.drawText(0, yOffset + fontAscent, num);
+            p.drawText(m_pDiffTextWindow->contentsMargins().left(), yOffset + fontAscent, num);
         }
         if(!bWrapLine || wrapLineLength > 0)
         {
@@ -1270,7 +1303,7 @@ void DiffTextWindow::paintEvent(QPaintEvent* e)
     p.setFont(font());
     p.QPainter::fillRect(invalidRect, gOptions->backgroundColor());
 
-    d->draw(p, invalidRect, d->m_firstLine, endLine);
+    draw(p, invalidRect, d->m_firstLine, endLine);
     p.end();
 
     d->m_oldFirstLine = d->m_firstLine;
@@ -1287,38 +1320,17 @@ void DiffTextWindow::print(RLPainter& p, const QRect&, qint32 firstLine, const L
     d->m_firstLine = firstLine;
     QRect invalidRect = QRect(0, 0, 1000000000, 1000000000);
     gOptions->beginPrint();
-    d->draw(p, invalidRect, firstLine, std::min(firstLine + nofLinesPerPage, getNofLines()));
+    draw(p, invalidRect, firstLine, std::min(firstLine + nofLinesPerPage, getNofLines()));
     gOptions->endPrint();
     d->m_firstLine = oldFirstLine;
 }
 
-void DiffTextWindowData::draw(RLPainter& p, const QRect& invalidRect, const qint32 beginLine, const LineRef& endLine)
+void DiffTextWindow::draw(RLPainter& p, const QRect& invalidRect, const qint32 beginLine, const LineRef& endLine)
 {
-    if(m_pLineData == nullptr || m_pLineData->empty()) return;
-    //TODO: Fix after line number area is converted to a QWidget.
-    m_lineNumberWidth = gOptions->m_bShowLineNumbers ? m_pDiffTextWindow->getLineNumberWidth() : 0;
+    if(!d->hasLineData()) return;
 
-    if(getWindowIndex() == e_SrcSelector::A)
-    {
-        m_cThis = gOptions->aColor();
-        m_cDiff1 = gOptions->bColor();
-        m_cDiff2 = gOptions->cColor();
-    }
-    else if(getWindowIndex() == e_SrcSelector::B)
-    {
-        m_cThis = gOptions->bColor();
-        m_cDiff1 = gOptions->cColor();
-        m_cDiff2 = gOptions->aColor();
-    }
-    else if(getWindowIndex() == e_SrcSelector::C)
-    {
-        m_cThis = gOptions->cColor();
-        m_cDiff1 = gOptions->aColor();
-        m_cDiff2 = gOptions->bColor();
-    }
-    m_cDiffBoth = gOptions->conflictColor(); // Conflict color
-
-    p.setPen(m_cThis);
+    d->initColors();
+    p.setPen(d->thisColor());
 
     for(qint32 line = beginLine; line < endLine; ++line)
     {
@@ -1326,17 +1338,17 @@ void DiffTextWindowData::draw(RLPainter& p, const QRect& invalidRect, const qint
         qint32 wrapLineLength = 0;
         const Diff3Line* d3l = nullptr;
         bool bWrapLine = false;
-        if(m_bWordWrap)
+        if(d->m_bWordWrap)
         {
-            Diff3WrapLine& d3wl = m_diff3WrapLineVector[line];
+            const Diff3WrapLine& d3wl = d->getDiff3WrapLineVector()[line];
             wrapLineOffset = d3wl.wrapLineOffset;
             wrapLineLength = d3wl.wrapLineLength;
             d3l = d3wl.pD3L;
-            bWrapLine = line > 0 && m_diff3WrapLineVector[line - 1].pD3L == d3l;
+            bWrapLine = line > 0 && d->getDiff3WrapLineVector()[line - 1].pD3L == d3l;
         }
         else
         {
-            d3l = (*mDiff3LineVector)[line];
+            d3l = (*d->diff3LineVector())[line];
         }
         std::shared_ptr<const DiffList> pFineDiff1;
         std::shared_ptr<const DiffList> pFineDiff2;
@@ -1346,9 +1358,8 @@ void DiffTextWindowData::draw(RLPainter& p, const QRect& invalidRect, const qint
         LineRef srcLineIdx;
         d3l->getLineInfo(getWindowIndex(), KDiff3App::isTripleDiff(), srcLineIdx, pFineDiff1, pFineDiff2, changed, changed2);
 
-        writeLine(
-            p,                                                             // QPainter
-            !srcLineIdx.isValid() ? nullptr : &(*m_pLineData)[srcLineIdx], // Text in this line
+        d->writeLine(
+            p, // QPainter
             pFineDiff1,
             pFineDiff2,
             line, // Line on the screen
@@ -1366,7 +1377,7 @@ QString DiffTextWindowData::getString(const LineType d3lIdx) const
 {
     assert(!(m_pLineData != nullptr && m_pLineData->empty() && m_size != 0));
 
-    if(m_pLineData == nullptr || m_pLineData->empty() || d3lIdx < 0 || d3lIdx >= mDiff3LineVector->size())
+    if(m_pLineData == nullptr || m_pLineData->empty() || d3lIdx < 0 || (size_t)d3lIdx >= mDiff3LineVector->size())
         return QString();
 
     const Diff3Line* d3l = (*mDiff3LineVector)[d3lIdx];
@@ -1380,9 +1391,10 @@ QString DiffTextWindowData::getString(const LineType d3lIdx) const
 
 QString DiffTextWindowData::getLineString(const LineType line) const
 {
+    //assert(line > 0);
     if(m_bWordWrap)
     {
-        if(line < m_diff3WrapLineVector.count())
+        if((size_t)line < m_diff3WrapLineVector.size())
         {
             LineType d3LIdx = m_pDiffTextWindow->convertLineToDiff3LineIdx(line);
             return getString(d3LIdx).mid(m_diff3WrapLineVector[line].wrapLineOffset, m_diff3WrapLineVector[line].wrapLineLength);
@@ -1436,8 +1448,8 @@ QString DiffTextWindow::getSelection() const
     LineRef line = 0;
     LineType lineIdx = 0;
 
-    QtSizeType it;
-    QtSizeType vectorSize = d->m_bWordWrap ? d->m_diff3WrapLineVector.size() : d->getDiff3LineVector()->size();
+    qsizetype it;
+    qsizetype vectorSize = d->m_bWordWrap ? d->m_diff3WrapLineVector.size() : d->getDiff3LineVector()->size();
     for(it = 0; it < vectorSize; ++it)
     {
         const Diff3Line* d3l = d->m_bWordWrap ? d->m_diff3WrapLineVector[it].pD3L : (*d->getDiff3LineVector())[it];
@@ -1459,7 +1471,7 @@ QString DiffTextWindow::getSelection() const
 
         if(lineIdx != LineRef::invalid)
         {
-            QtSizeType size = (*d->m_pLineData)[lineIdx].size();
+            qsizetype size = (*d->m_pLineData)[lineIdx].size();
             QString lineString = (*d->m_pLineData)[lineIdx].getLine();
 
             if(d->m_bWordWrap)
@@ -1468,7 +1480,7 @@ QString DiffTextWindow::getSelection() const
                 lineString = lineString.mid(d->m_diff3WrapLineVector[it].wrapLineOffset, size);
             }
 
-            for(QtSizeType i = 0; i < size; ++i)
+            for(qsizetype i = 0; i < size; ++i)
             {
                 if(d->m_selection.within(line, i))
                 {
@@ -1492,19 +1504,19 @@ QString DiffTextWindow::getSelection() const
     return selectionString;
 }
 
-bool DiffTextWindow::findString(const QString& s, LineRef& d3vLine, QtSizeType& posInLine, bool bDirDown, bool bCaseSensitive)
+bool DiffTextWindow::findString(const QString& s, LineRef& d3vLine, qsizetype& posInLine, bool bDirDown, bool bCaseSensitive)
 {
     LineRef it = d3vLine;
-    QtSizeType endIt = bDirDown ? d->getDiff3LineVector()->size() : -1;
+    qsizetype endIt = bDirDown ? d->getDiff3LineVector()->size() : -1;
     qint32 step = bDirDown ? 1 : -1;
-    QtSizeType startPos = posInLine;
+    qsizetype startPos = posInLine;
 
     for(; it != endIt; it += step)
     {
         QString line = d->getString(it);
         if(!line.isEmpty())
         {
-            QtSizeType pos = line.indexOf(s, startPos, bCaseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
+            qsizetype pos = line.indexOf(s, startPos, bCaseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
             //TODO: Provide error message when failsafe is triggered.
             if(Q_UNLIKELY(pos > limits<qint32>::max()))
             {
@@ -1516,6 +1528,11 @@ bool DiffTextWindow::findString(const QString& s, LineRef& d3vLine, QtSizeType&
             {
                 d3vLine = it;
                 posInLine = pos;
+
+                setSelection(d3vLine, posInLine, d3vLine, posInLine + s.length());
+                mVScrollBar->setValue(d->m_selection.beginLine() - DiffTextWindow::mVScrollBar->pageStep() / 2);
+
+                scrollToH(d->m_selection.beginPos());
                 return true;
             }
 
@@ -1525,11 +1542,11 @@ bool DiffTextWindow::findString(const QString& s, LineRef& d3vLine, QtSizeType&
     return false;
 }
 
-void DiffTextWindow::convertD3LCoordsToLineCoords(LineType d3LIdx, QtSizeType d3LPos, LineRef& line, QtSizeType& pos) const
+void DiffTextWindow::convertD3LCoordsToLineCoords(LineType d3LIdx, qsizetype d3LPos, LineRef& line, qsizetype& pos) const
 {
     if(d->m_bWordWrap)
     {
-        QtSizeType wrapPos = d3LPos;
+        qsizetype wrapPos = d3LPos;
         LineRef wrapLine = convertDiff3LineIdxToLine(d3LIdx);
         while(wrapPos > d->m_diff3WrapLineVector[wrapLine].wrapLineLength)
         {
@@ -1546,7 +1563,7 @@ void DiffTextWindow::convertD3LCoordsToLineCoords(LineType d3LIdx, QtSizeType d3
     }
 }
 
-void DiffTextWindow::convertLineCoordsToD3LCoords(LineRef line, QtSizeType pos, LineType& d3LIdx, QtSizeType& d3LPos) const
+void DiffTextWindow::convertLineCoordsToD3LCoords(LineRef line, qsizetype pos, LineType& d3LIdx, qsizetype& d3LPos) const
 {
     if(d->m_bWordWrap && !d->m_diff3WrapLineVector.empty())
     {
@@ -1566,7 +1583,7 @@ void DiffTextWindow::convertLineCoordsToD3LCoords(LineRef line, QtSizeType pos,
     }
 }
 
-void DiffTextWindow::setSelection(LineRef firstLine, QtSizeType startPos, LineRef lastLine, QtSizeType endPos, LineRef& l, QtSizeType& p)
+void DiffTextWindow::setSelection(LineRef firstLine, qsizetype startPos, LineRef lastLine, qsizetype endPos)
 {
     d->m_selection.reset();
     if(lastLine >= getNofLines())
@@ -1586,7 +1603,7 @@ void DiffTextWindow::setSelection(LineRef firstLine, QtSizeType startPos, LineRe
     {
         QString s1 = d->getString(firstLine);
         LineRef firstWrapLine = convertDiff3LineIdxToLine(firstLine);
-        QtSizeType wrapStartPos = startPos;
+        qsizetype wrapStartPos = startPos;
         while(wrapStartPos > d->m_diff3WrapLineVector[firstWrapLine].wrapLineLength)
         {
             wrapStartPos -= d->m_diff3WrapLineVector[firstWrapLine].wrapLineLength;
@@ -1596,7 +1613,7 @@ void DiffTextWindow::setSelection(LineRef firstLine, QtSizeType startPos, LineRe
 
         QString s2 = d->getString(lastLine);
         LineRef lastWrapLine = convertDiff3LineIdxToLine(lastLine);
-        QtSizeType wrapEndPos = endPos;
+        qsizetype wrapEndPos = endPos;
         while(wrapEndPos > d->m_diff3WrapLineVector[lastWrapLine].wrapLineLength)
         {
             wrapEndPos -= d->m_diff3WrapLineVector[lastWrapLine].wrapLineLength;
@@ -1606,8 +1623,6 @@ void DiffTextWindow::setSelection(LineRef firstLine, QtSizeType startPos, LineRe
 
         d->m_selection.start(firstWrapLine, wrapStartPos);
         d->m_selection.end(lastWrapLine, wrapEndPos);
-        l = firstWrapLine;
-        p = wrapStartPos;
     }
     else
     {
@@ -1615,10 +1630,9 @@ void DiffTextWindow::setSelection(LineRef firstLine, QtSizeType startPos, LineRe
         {
             d->m_selection.start(firstLine, startPos);
             d->m_selection.end(lastLine, endPos);
-            l = firstLine;
-            p = startPos;
         }
     }
+
     update();
 }
 
@@ -1629,10 +1643,10 @@ LineRef DiffTextWindowData::convertLineOnScreenToLineInSource(const qint32 lineO
     {
         if(coordType == eWrapCoords) return lineOnScreen;
         LineType d3lIdx = m_pDiffTextWindow->convertLineToDiff3LineIdx(lineOnScreen);
-        if(!bFirstLine && d3lIdx >= mDiff3LineVector->size())
+        if(!bFirstLine && d3lIdx >= SafeInt<LineType>(mDiff3LineVector->size()))
             d3lIdx = SafeInt<LineType>(mDiff3LineVector->size() - 1);
         if(coordType == eD3LLineCoords) return d3lIdx;
-        while(!line.isValid() && d3lIdx < mDiff3LineVector->size() && d3lIdx >= 0)
+        while(!line.isValid() && d3lIdx < SafeInt<LineType>(mDiff3LineVector->size()) && d3lIdx >= 0)
         {
             const Diff3Line* d3l = (*mDiff3LineVector)[d3lIdx];
             if(getWindowIndex() == e_SrcSelector::A) line = d3l->getLineA();
@@ -1665,13 +1679,13 @@ void DiffTextWindow::convertSelectionToD3LCoords() const
 
     // convert the d->m_selection to unwrapped coordinates: Later restore to new coords
     LineType firstD3LIdx;
-    QtSizeType firstD3LPos;
-    QtSizeType firstPosInText = d->m_selection.beginPos();
+    qsizetype firstD3LPos;
+    qsizetype firstPosInText = d->m_selection.beginPos();
     convertLineCoordsToD3LCoords(d->m_selection.beginLine(), firstPosInText, firstD3LIdx, firstD3LPos);
 
     LineType lastD3LIdx;
-    QtSizeType lastD3LPos;
-    QtSizeType lastPosInText = d->m_selection.endPos();
+    qsizetype lastD3LPos;
+    qsizetype lastPosInText = d->m_selection.endPos();
     convertLineCoordsToD3LCoords(d->m_selection.endLine(), lastPosInText, lastD3LIdx, lastD3LPos);
 
     d->m_selection.start(firstD3LIdx, firstD3LPos);
@@ -1704,7 +1718,7 @@ bool DiffTextWindow::startRunnables()
     }
 }
 
-void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSize, qint32 visibleTextWidth)
+void DiffTextWindow::recalcWordWrap(bool bWordWrap, size_t wrapLineVectorSize, qint32 visibleTextWidth)
 {
     if(d->getDiff3LineVector() == nullptr || !isVisible())
     {
@@ -1717,16 +1731,13 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
 
     if(bWordWrap)
     {
-        //TODO: Fix after line number area is converted to a QWidget.
-        d->m_lineNumberWidth = gOptions->m_bShowLineNumbers ? getLineNumberWidth() : 0;
-
         d->m_diff3WrapLineVector.resize(wrapLineVectorSize);
 
         if(wrapLineVectorSize == 0)
         {
             d->m_wrapLineCacheList.clear();
             setUpdatesEnabled(false);
-            for(QtSizeType i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
+            for(size_t i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
             {
                 d->m_wrapLineCacheList.push_back(std::vector<WrapLineCacheData>());
                 s_runnables.push_back(new RecalcWordWrapThread(this, visibleTextWidth, j));
@@ -1745,7 +1756,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
             d->m_diff3WrapLineVector.resize(0);
             d->m_wrapLineCacheList.clear();
             setUpdatesEnabled(false);
-            for(qint32 i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
+            for(size_t i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
             {
                 s_runnables.push_back(new RecalcWordWrapThread(this, visibleTextWidth, j));
             }
@@ -1757,7 +1768,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
     }
 }
 
-void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, qint32 visibleTextWidth, size_t cacheListIdx)
+void DiffTextWindow::recalcWordWrapHelper(size_t wrapLineVectorSize, qint32 visibleTextWidth, size_t cacheListIdx)
 {
     if(d->m_bWordWrap)
     {
@@ -1768,10 +1779,10 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, qint32
         else //TODO: Drop after line number area is converted to a QWidget.
             visibleTextWidth -= d->leftInfoWidth() * fontMetrics().horizontalAdvance('0');
         LineType i;
-        QtSizeType wrapLineIdx = 0;
-        QtSizeType size = d->getDiff3LineVector()->size();
+        size_t wrapLineIdx = 0;
+        size_t size = d->getDiff3LineVector()->size();
         LineType firstD3LineIdx = SafeInt<LineType>(wrapLineVectorSize > 0 ? 0 : cacheListIdx * s_linesPerRunnable);
-        LineType endIdx = SafeInt<LineType>(wrapLineVectorSize > 0 ? size : std::min<QtSizeType>(firstD3LineIdx + s_linesPerRunnable, size));
+        LineType endIdx = SafeInt<LineType>(wrapLineVectorSize > 0 ? size : std::min<size_t>(firstD3LineIdx + s_linesPerRunnable, size));
         std::vector<WrapLineCacheData>& wrapLineCache = d->m_wrapLineCacheList[cacheListIdx];
         size_t cacheListIdx2 = 0;
         QTextLayout textLayout(QString(), font(), this);
@@ -1861,7 +1872,7 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, qint32
         if(wrapLineVectorSize > 0)
         {
             assert(wrapLineVectorSize <= limits<LineType>::max()); //Posiable but unlikely starting in Qt6
-            d->m_firstLine = (LineType)std::min<SafeInt<LineType>>(d->m_firstLine, wrapLineVectorSize - 1);
+            d->m_firstLine = std::min<LineRef>(d->m_firstLine, wrapLineVectorSize - 1);
             d->m_horizScrollOffset = 0;
 
             Q_EMIT firstLineChanged(d->m_firstLine);
@@ -1872,7 +1883,7 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, qint32
         if(ProgressProxy::wasCancelled())
             return;
 
-        QtSizeType size = d->getDiff3LineVector()->size();
+        size_t size = d->getDiff3LineVector()->size();
         LineType firstD3LineIdx = SafeInt<LineType>(cacheListIdx * s_linesPerRunnable);
         LineType endIdx = std::min(firstD3LineIdx + s_linesPerRunnable, (LineType)size);
 
@@ -1907,11 +1918,11 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, qint32
 
         // convert the d->m_selection to unwrapped coordinates.
         LineRef firstLine;
-        QtSizeType firstPos;
+        qsizetype firstPos;
         convertD3LCoordsToLineCoords(d->m_selection.beginLine(), d->m_selection.beginPos(), firstLine, firstPos);
 
         LineRef lastLine;
-        QtSizeType lastPos;
+        qsizetype lastPos;
         convertD3LCoordsToLineCoords(d->m_selection.endLine(), d->m_selection.endPos(), lastLine, lastPos);
 
         d->m_selection.start(firstLine, firstPos);
@@ -1940,6 +1951,7 @@ DiffTextWindowFrame::DiffTextWindowFrame(QWidget* pParent, e_SrcSelector winIdx,
     chk_connect_a(m_pFileSelection, &QLineEdit::returnPressed, this, &DiffTextWindowFrame::slotReturnPressed);
 
     m_pDiffTextWindow = new DiffTextWindow(this, winIdx, app);
+    m_pDiffTextWindow->setContentsMargins(4, 4, 4, 4); // (left, top, right, bottom)
     m_pDiffTextWindow->setSourceData(psd);
     QVBoxLayout* pVTopLayout = new QVBoxLayout(m_pTopLineWidget);
     pVTopLayout->setContentsMargins(2, 2, 2, 2);
@@ -2009,7 +2021,7 @@ void DiffTextWindowFrame::setupConnections(const KDiff3App* app)
 LineRef DiffTextWindow::calcTopLineInFile(const LineRef firstLine) const
 {
     LineRef currentLine;
-    for(QtSizeType i = convertLineToDiff3LineIdx(firstLine); i < d->getDiff3LineVector()->size(); ++i)
+    for(size_t i = convertLineToDiff3LineIdx(firstLine); i < d->getDiff3LineVector()->size(); ++i)
     {
         const Diff3Line* d3l = (*d->getDiff3LineVector())[i];
         currentLine = d3l->getLineInFile(getWindowIndex());
@@ -2028,7 +2040,8 @@ void DiffTextWindowFrame::setFirstLine(const LineRef firstLine)
 
         LineRef topVisiableLine = pDTW->calcTopLineInFile(firstLine);
 
-        qint32 w = m_pTopLine->fontMetrics().horizontalAdvance(s + ' ' + QString().fill('0', lineNumberWidth));
+        const QString widthString = QString().fill('0', lineNumberWidth);
+        qint32 w = m_pTopLine->fontMetrics().horizontalAdvance(s + ' ' + widthString);
         m_pTopLine->setMinimumWidth(w);
 
         if(!topVisiableLine.isValid())
@@ -2131,21 +2144,12 @@ void EncodingLabel::mousePressEvent(QMouseEvent*)
 
         const QByteArray& currentTextCodec = m_pSourceData->getEncoding(); // the codec that will be checked in the context menu
 
-        const QList<int> mibs = QTextCodec::availableMibs();
-        QList<QByteArray> names;
+        const QStringList names= Utils::availableCodecs();
         QList<QByteArray> codecNameList;
-        for(const qint32 mib: mibs)
-        {
-            names.append(QTextCodec::codecForMib(mib)->name());
-        }
-
         // Adding "main" encodings
         insertCodec(i18n("Unicode, 8 bit"), "UTF-8", codecNameList, m_pContextEncodingMenu, currentTextCodec);
         insertCodec(i18n("Unicode, 8 bit (BOM)"), "UTF-8-BOM", codecNameList, m_pContextEncodingMenu, currentTextCodec);
-        if(QTextCodec::codecForName("System"))
-        {
-            insertCodec(QString(), "System", codecNameList, m_pContextEncodingMenu, currentTextCodec);
-        }
+        insertCodec(i18n("System"), QStringConverter::nameForEncoding(QStringConverter::System), codecNameList, m_pContextEncodingMenu, currentTextCodec);
 
         // Adding recent encodings
         if(gOptions != nullptr)
@@ -2158,9 +2162,9 @@ void EncodingLabel::mousePressEvent(QMouseEvent*)
         }
         // Submenu to add the rest of available encodings
         pContextEncodingSubMenu->setTitle(i18n("Other"));
-        for(const QByteArray& name: names)
+        for(const QString& name: names)
         {
-            insertCodec("", name, codecNameList, pContextEncodingSubMenu, currentTextCodec);
+            insertCodec("", name.toLatin1(), codecNameList, pContextEncodingSubMenu, currentTextCodec);
         }
 
         m_pContextEncodingMenu->addMenu(pContextEncodingSubMenu);
