@@ -11,14 +11,12 @@
 #ifndef KDIFF3_H
 #define KDIFF3_H
 
-#include "diff.h"
 #include "defmac.h"
-#include "combiners.h"
+#include "diff.h"
 #include "SourceData.h"
+#include "StandardMenus.h"
 #include "TypeUtils.h"
 
-#include <boost/signals2.hpp>
-
 #include <memory>
 
 // include files for Qt
@@ -60,6 +58,8 @@ class KDiff3Shell;
 class DirectoryMergeWindow;
 class DirectoryMergeInfo;
 
+class StandardMenus;
+
 class ReversibleScrollBar : public QScrollBar
 {
     Q_OBJECT
@@ -163,9 +163,7 @@ class KDiff3App: public QMainWindow
 
     [[nodiscard]] KActionCollection* actionCollection() const;
 
-    static boost::signals2::signal<QString (), FirstNonEmpty<QString>> getSelection;
-    static boost::signals2::signal<bool(), or_> allowCopy;
-    static boost::signals2::signal<bool(), or_> allowCut;
+    static boost::signals2::signal<QString(), FirstNonEmpty<QString>> getSelection;
 
     bool canContinue();
 
@@ -262,29 +260,15 @@ public Q_SLOTS:
     void slotEditSelectAll();
     void slotEditFind();
     void slotEditFindNext();
-    void slotGoCurrent();
-    void slotGoTop();
-    void slotGoBottom();
-    void slotGoPrevUnsolvedConflict();
     void slotGoNextUnsolvedConflict();
-    void slotGoPrevConflict();
     void slotGoNextConflict();
-    void slotGoPrevDelta();
-    void slotGoNextDelta();
     void slotGoToLine();
-    void slotChooseA();
-    void slotChooseB();
-    void slotChooseC();
     void slotAutoSolve();
-    void slotUnsolve();
-    void slotMergeHistory();
-    void slotRegExpAutoMerge();
     void slotConfigure();
     void slotConfigureKeys();
     void slotRefresh();
     void slotSelectionEnd();
     void slotSelectionStart();
-    void slotClipboardChanged();
     void slotOutputModified(bool);
     void slotFinishMainInit();
     void slotMergeCurrentFile();
@@ -314,7 +298,9 @@ public Q_SLOTS:
 
     void setHScrollBarRange();
 
-    void slotFocusChanged(QWidget *old, QWidget *now);
+    void slotFocusChanged(QWidget* old, QWidget* now);
+    void slotScrollToH(qsizetype p);
+
   Q_SIGNALS:
     void updateAvailabilities();
 
@@ -330,6 +316,7 @@ public Q_SLOTS:
 
   private:
     void mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFlags = InitFlag::defaultFlags);
+    void resetDiffData();
     void mainWindowEnable(bool bEnable);
     void wheelEvent(QWheelEvent* pWheelEvent) override;
     void keyPressEvent(QKeyEvent* event) override;
@@ -345,23 +332,12 @@ public Q_SLOTS:
     [[nodiscard]] KToolBar* toolBar(const QLatin1String &toolBarId) const;
     void recalcWordWrap(qint32 visibleTextWidthForPrinting = -1);
 
+    bool canSave();
+    bool canSaveAs();
     bool canCut();
     bool canCopy();
 
-    bool mInitCalled = false;
-
-    // QAction pointers to enable/disable actions
-    QPointer<QAction> fileOpen;
-    QPointer<QAction> fileSave;
-    QPointer<QAction> fileSaveAs;
-    QPointer<QAction> filePrint;
-    QPointer<QAction> fileQuit;
-    QPointer<QAction> fileReload;
-    QPointer<QAction> editUndo;
-    QPointer<QAction> editCut;
-    QPointer<QAction> editCopy;
-    QPointer<QAction> editPaste;
-    QPointer<QAction> editSelectAll;
+    std::unique_ptr<StandardMenus> stdMenus = std::make_unique<StandardMenus>();
     KToggleAction* viewStatusBar = nullptr;
 
     QPointer<QShortcut> mEscapeAction;
