@@ -130,7 +130,7 @@ OpenDialog::OpenDialog(
         This makes behavior consitant with the main window.
 
         On windows this step also needed to bypasses Qt's quirky behavior when converting from QUrl
-        to QString. Specifically % encoding is by handled differently on windows. This is explicitly documented
+        to QString. Specifically % encoding is handled differently on windows. This is explicitly documented
         as platform specific unspecified behavior. Not what we need.
     */
     dialogUi.lineA->setLineEdit(new FileNameLineEdit(dialogUi.lineA));
@@ -202,7 +202,7 @@ void OpenDialog::inputFilenameChanged()
 void OpenDialog::fixCurrentText(QComboBox* pCB)
 {
     QString s = pCB->currentText();
-    QtSizeType pos = s.indexOf('\n');
+    qsizetype pos = s.indexOf('\n');
 
     if(pos >= 0)
         s = s.left(pos);
@@ -240,7 +240,7 @@ void OpenDialog::accept()
 
 void OpenDialog::slotSwapCopyNames(QAction* pAction) const // id selected in the popup menu
 {
-    const QtSizeType id = pAction->parentWidget()->actions().indexOf(pAction);
+    const qsizetype id = qobject_cast<QWidget*>(pAction->parent())->actions().indexOf(pAction);
     QComboBox* cb1 = nullptr;
     QComboBox* cb2 = nullptr;
 
