@@ -105,7 +105,7 @@ class FindDialog: public QDialog
         {
             case eWindowIndex::invalid:
                 qCWarning(kdiffMain) << "FindDialog::nextWindow called with invalid state.";
-                Q_FALLTHROUGH();
+                [[fallthrough]];
             case eWindowIndex::None:
                 currentWindow = eWindowIndex::A;
                 break;
@@ -138,7 +138,7 @@ class FindDialog: public QDialog
     QCheckBox* m_pCaseSensitive;
 
     LineRef currentLine = 0;
-    QtSizeType currentPos = 0;
+    qsizetype currentPos = 0;
 
   private:
     eWindowIndex currentWindow = eWindowIndex::None;
